#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:               haskell-gi-overloading
version:            1.0
visibility:         public
id:                 haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf
key:                haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf
license:            BSD-3-Clause
copyright:          Iñaki García Etxebarria
maintainer:         garetxe@gmail.com
author:             Iñaki García Etxebarria
homepage:           https://github.com/haskell-gi/haskell-gi
synopsis:           Overloading support for haskell-gi
description:
    Control overloading support in haskell-gi generated bindings

category:           Bindings
abi:                b5b1ee83e144b210df86b7b6143425d4
exposed:            True
data-dir:           /usr/share/i386-linux-ghc-8.10.5/haskell-gi-overloading-1.0
haddock-interfaces:
    /usr/share/doc/haskell-gi-overloading/html/haskell-gi-overloading.haddock

haddock-html:       /usr/share/doc/haskell-gi-overloading/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

